function x = NLBP_CVX(y,Q,epsilon,lambda,n)
%x = NLBP_CVX(y,Q,epsilon,lambda)
%
% Computes the solution to
%
% min_X Tr(X) + lambda*||X||_1
%  s.t. ||sum_i b(i) - Tr(Q(:,:,i)*X)||< epsilon,
%       X >= 0.        
%
% and returns X(2:n+1,1)
% Written by Henrik Ohlsson, ohlsson@isy.liu.se

[m N]=size(squeeze(Q(:,1,:)));

%% CVX to solve the NLBP problem
cvx_begin SDP quiet
variable X(m,m) symmetric
variable e(N,1)  
variable traceVector(N,1) 
minimize(trace(X) + lambda*sum(norms(X,1,1)))
subject to
for r=1:N
    traceVector(r,1) == trace(squeeze(Q(:,:,r))*X);
end
norms(traceVector-y) <= epsilon
X>=0
cvx_end

x=X(2:n+1,1);

